@@ -253,6 +253,8 @@ bjb_controller_add_item (BjbController *self,
   GtkListStore  *store;
   GdkPixbuf     *pix = NULL;
   const gchar   *uuid;
+  BjbWindowBase  *win;
+  BjbWindowViewType type;
 
   g_return_if_fail (BIJI_IS_ITEM (item));
   store = GTK_LIST_STORE (self->priv->model);
@@ -275,10 +277,13 @@ bjb_controller_add_item (BjbController *self,
 
   /* First , if there is a gd main view , and if gd main view
    * is a list, then load the smaller emblem */
-  if (bjb_window_base_get_view_type (self->priv->window) == BJB_WINDOW_BASE_MAIN_VIEW
-      && bjb_window_base_get_main_view (self->priv->window)
+  win = self->priv->window;
+  type = bjb_window_base_get_view_type (win);
+  if ((type == BJB_WINDOW_BASE_MAIN_VIEW ||
+       type == BJB_WINDOW_BASE_ARCHIVE_VIEW)
+      && bjb_window_base_get_main_view (win)
       && bjb_main_view_get_view_type
-                (bjb_window_base_get_main_view (self->priv->window)) == GD_MAIN_VIEW_LIST)
+                (bjb_window_base_get_main_view (win)) == GD_MAIN_VIEW_LIST)
     pix = biji_item_get_emblem (item);
 
   /* Else, load the icon */
@@ -617,8 +622,8 @@ on_manager_changed (BijiManager            *manager,
       break;
 
     case BIJI_MANAGER_ITEM_DELETED:
-      g_warning ("on item deleted");
     case BIJI_MANAGER_ITEM_TRASHED:
+    case BIJI_MANAGER_ITEM_RESTORED:
       if (bjb_controller_get_iter (self, item, &p_iter))
         gtk_list_store_remove (GTK_LIST_STORE (priv->model), p_iter);
 
@@ -626,7 +631,6 @@ on_manager_changed (BijiManager            *manager,
       notify_displayed_items_changed (self);
       break;
 
-
     default:
       bjb_controller_apply_needle (self);
       if (flag == BIJI_MANAGER_MASS_CHANGE)
@@ -857,8 +861,10 @@ bjb_controller_set_group (BjbController   *self,
   }
 
 
-  /* Archives : ping the manager */
-  biji_manager_load_archives (self->priv->manager);
+  else /* Archives */
+  {
+    bjb_controller_apply_needle (self);
+  }
 }
 
 
