@@ -184,6 +184,13 @@ local_note_archive (BijiNoteObj *note)
     g_message ("%s", error->message);
     g_error_free (error);
     error = NULL;
+    g_object_unref (archive);
+  }
+
+  else
+  {
+    g_object_unref (self->priv->location);
+    self->priv->location = archive;
   }
 
 
@@ -192,14 +199,13 @@ local_note_archive (BijiNoteObj *note)
   g_free (trash_path);
   g_object_unref (trash);
   g_free (backup_path);
-  g_object_unref (archive);
 
   return result;
 }
 
 
 static gboolean
-local_note_restore (BijiItem *item)
+local_note_restore (BijiItem *item, gchar **old_uuid)
 {
   BijiLocalNote *self;
   gchar *root_path, *path;
@@ -233,6 +239,7 @@ local_note_restore (BijiItem *item)
     g_error_free (error);
   }
 
+  *old_uuid = g_file_get_path (self->priv->location);
   g_object_unref (self->priv->location);
   g_object_unref (trash);
   g_object_unref (root);
