@@ -96,16 +96,16 @@ biji_manager_init (BijiManager *self)
   priv->items = g_hash_table_new_full (g_str_hash,
                                        g_str_equal,
                                        NULL,
-                                       g_object_unref);
+                                       NULL);
 
   priv->archives = g_hash_table_new_full (g_str_hash,
                                           g_str_equal,
                                           NULL,
-                                          g_object_unref);
+                                          NULL);
   /*
    * Providers are the different notes storage
    * the hash table use an id
-   * 
+   *
    * - local files stored notes = "local"
    * - own cloud notes = account_get_id
    */
@@ -298,6 +298,29 @@ on_item_deleted_cb (BijiItem *item, BijiManager *manager)
 }
 
 
+/*
+ * old uuid : we need this because local provider uses
+ * file name as uuid. Now this proves this is not right.
+ *
+ * notify... BIJI_ARCHIVED_ITEM
+ * well, works currently : we assume Archives change.
+ * but we might double-ping as well
+ * or improve the whole logic
+ */
+static void
+on_item_restored_cb (BijiItem *item, gchar *old_uuid, BijiManager *manager)
+{
+  g_hash_table_insert (manager->priv->items,
+                       (gpointer) biji_item_get_uuid (item), item);
+  g_hash_table_remove (manager->priv->archives, old_uuid);
+
+  biji_manager_notify_changed (manager,
+                               BIJI_ARCHIVED_ITEMS,
+                               BIJI_MANAGER_ITEM_DELETED,
+                               item);
+}
+
+
 void
 manager_on_note_changed_cb (BijiNoteObj *note, BijiManager *manager)
 {
@@ -360,7 +383,10 @@ biji_manager_add_item (BijiManager *manager,
                            (gpointer) biji_item_get_uuid (item), item);
 
     /* Connect */
-    g_signal_connect (item, "deleted", G_CALLBACK (on_item_deleted_cb), manager);
+    g_signal_connect (item, "deleted",
+                      G_CALLBACK (on_item_deleted_cb), manager);
+    g_signal_connect (item, "restored",
+                      G_CALLBACK (on_item_restored_cb), manager);
 
     if (BIJI_IS_NOTE_OBJ (item))
     {
@@ -591,6 +617,8 @@ biji_manager_remove_item (BijiManager *manager, BijiItem *item)
      * fully available for signal receiver. */
     biji_manager_notify_changed (manager, BIJI_LIVING_ITEMS, BIJI_MANAGER_ITEM_TRASHED, to_delete);
     biji_item_trash (item);
+    g_hash_table_insert (manager->priv->archives,
+                         (gpointer) biji_item_get_uuid (item), item);
     g_hash_table_remove (manager->priv->items, path);
 
     retval = TRUE;
@@ -771,7 +799,7 @@ biji_manager_local_note_new           (BijiManager *manager, gchar *str)
   }
 
   biji_note_obj_save_note (ret);
-  biji_manager_add_item (manager, BIJI_ITEM (ret), TRUE, BIJI_LIVING_ITEMS);
+  biji_manager_add_item (manager, BIJI_ITEM (ret), BIJI_LIVING_ITEMS, TRUE);
 
   return ret;
 }
@@ -821,7 +849,7 @@ biji_manager_note_new            (BijiManager *manager,
   retval = BIJI_PROVIDER_GET_CLASS (provider)->create_new_note (provider, str);
   // do not save. up to the provider implementation to save it or not
   // at creation.
-  biji_manager_add_item (manager, BIJI_ITEM (retval), TRUE, BIJI_LIVING_ITEMS);
+  biji_manager_add_item (manager, BIJI_ITEM (retval), BIJI_LIVING_ITEMS, TRUE);
 
   return retval;
 }
